Stan Math Library: stan/math/fwd/mat/fun/dot_self.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
dot_self.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/err/check_vector.hpp>`
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/fwd/mat/fun/dot_product.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , int R, int C>
fvar< T > | stan::math::dot_self (const Eigen::Matrix< fvar< T >, R, C > &v)

[ Stan Home Page ] © 2011–2016, Stan Development Team.